---
layout: landing
desciption: cash in on DNA barcode tags
---

# pycashier

:::{container} buttons

  [Docs](/installation)
  [Github](https://github.com/brocklab/pycashier)
  [Brock Lab Site](https://brocklab.com)

:::

Tool for extracting and processing DNA barcode tags from Illumina sequencing.
Default parameters are designed for use by the Brock Lab to process data generated from ClonMapper lineage tracing experiments, but is extensible to other similarly designed tools.

```{toctree}
:hidden:
:maxdepth: 2

installation.md
usage.md
cli
```

